/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*- */
/*
    This file is part of Déjà Dup.
    © 2008,2009 Michael Terry <mike@mterry.name>

    Déjà Dup is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Déjà Dup is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Déjà Dup.  If not, see <http://www.gnu.org/licenses/>.
*/

using GLib;

namespace DejaDup {

public const string FILE_PATH_KEY = "/apps/deja-dup/file/path";

public class BackendFile : Backend
{
  public BackendFile(Gtk.Window? win) {
    toplevel = win;
  }
  
  public override Backend clone() {
    return new BackendFile(toplevel);
  }

  string? get_location_from_gconf() throws Error
  {
    var client = get_gconf_client();
    var path = client.get_string(FILE_PATH_KEY);
    return path;
  }
  
  public override string? get_location() throws Error
  {
    var path = get_location_from_gconf();
    var file = File.parse_name(path);
    if (DuplicityInfo.get_default().has_native_gio)
      return file.get_uri();
    else {
      if (file.get_path() == null)
        throw new BackupError.BAD_CONFIG(_("GVFS FUSE is not installed"));
      return "file://" + file.get_path();
    }
  }

  public override string? get_location_pretty() throws Error
  {
    return get_location_from_gconf();
  }
  
  public override bool is_native() {
    try {
      var path = get_location_from_gconf();
      if (path != null) {
        var file = File.parse_name(path);
        return file.is_native();
      }
    }
    catch (Error e) {
      warning("%s\n", e.message);
    }

    return true; // default to yes?
  }

  public override void add_argv(Operation.Mode mode, ref List<string> argv)
  {
    if (mode == Operation.Mode.BACKUP) {
      try {
        var path = get_location_from_gconf();
        if (path != null) {
          var file = File.parse_name(path);
          if (file.is_native())
            argv.prepend("--exclude=%s".printf(file.get_path()));
        }
      }
      catch (Error e) {
        warning("%s\n", e.message);
      }
    }
    
    if (mode == Operation.Mode.INVALID && DuplicityInfo.get_default().has_native_gio)
      argv.prepend("--gio");
  }
  
  // This doesn't *really* worry about envp, it just is a convenient point to
  // hook into the operation steps to mount the file.
  public override void get_envp() throws Error
  {
    var path = get_location_from_gconf();
    var file = File.parse_name(path);
    Mount mount = null;
    if (!file.is_native()) {
      // Check if it's mounted
      try {
        mount = file.find_enclosing_mount(null);
      }
      catch (Error e) {}
      
      if (mount == null) {
        mount_file(file);
        return;
      }
    }
    
    envp_ready(true, new List<string>());
  }
  
  void mount_file(File file)
  {
    this.ref();
    file.mount_enclosing_volume(MountMountFlags.NONE, mount_op, null, (o, r) => {
      try {
        var success = ((File)o).mount_enclosing_volume_finish(r);
        envp_ready(success, new List<string>());
      }
      catch (Error e) {
        envp_ready(false, new List<string>(), e.message);
      }
      this.unref();
    });
  }
}

} // end namespace

